==> igniteui-react-charts-18.5.1.tgz: package/esm2015/lib/PercentageVolumeOscillatorIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { IShortPeriodLongPeriod_$type } from "./IShortPeriodLongPeriod";
import { PercentageVolumeOscillatorIndicatorStrategy } from "./PercentageVolumeOscillatorIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core";
/**
 * @hidden
 */
export let PercentageVolumeOscillatorIndicator = /*@__PURE__*/ (() => {
    class PercentageVolumeOscillatorIndicator extends StrategyBasedIndicator {
        bg() {
            return new PercentageVolumeOscillatorIndicator();
        }
        get_yz() {
            return new PercentageVolumeOscillatorIndicatorStrategy();
        }
        get yz() {
            return this.get_yz();
        }
        get_zc() {
            return PercentageVolumeOscillatorIndicator.$;
        }
        get zc() {
            return this.get_zc();
        }
        get shortPeriod() {
            return typeGetValue(this.c(PercentageVolumeOscillatorIndicator.zl));
        }
        set shortPeriod(a) {
            this.h(PercentageVolumeOscillatorIndicator.zl, a);
        }
        y7() {
            return this.shortPeriod;
        }
        get longPeriod() {
            return typeGetValue(this.c(PercentageVolumeOscillatorIndicator.zk));
        }
        set longPeriod(a) {
            this.h(PercentageVolumeOscillatorIndicator.zk, a);
        }
        y4() {
            return this.longPeriod;
        }
    }
    PercentageVolumeOscillatorIndicator.$t = /*@__PURE__*/ markType(PercentageVolumeOscillatorIndicator, 'PercentageVolumeOscillatorIndicator', StrategyBasedIndicator.$, [IShortPeriodLongPeriod_$type]);
    PercentageVolumeOscillatorIndicator.zl = /*@__PURE__*/ StrategyBasedIndicator.zj(10, PercentageVolumeOscillatorIndicator.$);
    PercentageVolumeOscillatorIndicator.zk = /*@__PURE__*/ StrategyBasedIndicator.zf(30, PercentageVolumeOscillatorIndicator.$);
    return PercentageVolumeOscillatorIndicator;
})();

==> igniteui-react-charts-18.6.0.tgz: package/esm2015/lib/PercentageVolumeOscillatorIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { IShortPeriodLongPeriod_$type } from "./IShortPeriodLongPeriod";
import { PercentageVolumeOscillatorIndicatorStrategy } from "./PercentageVolumeOscillatorIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core";
/**
 * @hidden
 */
export let PercentageVolumeOscillatorIndicator = /*@__PURE__*/ (() => {
    class PercentageVolumeOscillatorIndicator extends StrategyBasedIndicator {
        bc() {
            return new PercentageVolumeOscillatorIndicator();
        }
        get_y0() {
            return new PercentageVolumeOscillatorIndicatorStrategy();
        }
        get y0() {
            return this.get_y0();
        }
        get_zd() {
            return PercentageVolumeOscillatorIndicator.$;
        }
        get zd() {
            return this.get_zd();
        }
        get shortPeriod() {
            return typeGetValue(this.c(PercentageVolumeOscillatorIndicator.zm));
        }
        set shortPeriod(a) {
            this.h(PercentageVolumeOscillatorIndicator.zm, a);
        }
        y8() {
            return this.shortPeriod;
        }
        get longPeriod() {
            return typeGetValue(this.c(PercentageVolumeOscillatorIndicator.zl));
        }
        set longPeriod(a) {
            this.h(PercentageVolumeOscillatorIndicator.zl, a);
        }
        y5() {
            return this.longPeriod;
        }
    }
    PercentageVolumeOscillatorIndicator.$t = /*@__PURE__*/ markType(PercentageVolumeOscillatorIndicator, 'PercentageVolumeOscillatorIndicator', StrategyBasedIndicator.$, [IShortPeriodLongPeriod_$type]);
    PercentageVolumeOscillatorIndicator.zm = /*@__PURE__*/ StrategyBasedIndicator.zk(10, PercentageVolumeOscillatorIndicator.$);
    PercentageVolumeOscillatorIndicator.zl = /*@__PURE__*/ StrategyBasedIndicator.zg(30, PercentageVolumeOscillatorIndicator.$);
    return PercentageVolumeOscillatorIndicator;
})();
